@@ -55,9 +55,11 @@ def run():
     skipped_count = 0
     for file_name in files_to_check:
         candidates = known_by_calibre[file_size(file_name)]
-        if any(are_files_identical(file_name, c) for c in candidates):
-            print "Already present:", file_name
-            skipped_count += 1
+        for c in candidates:
+            if are_files_identical(file_name, c):
+                print "Already present: %s (stored as %s)" % (file_name, c)
+                skipped_count += 1
+                break
         else:
             print "Not registered by calibre:", file_name
             add_to_calibre(file_name)
